"""Script for running a tsunami inundation scenario for Cairns, QLD Australia.

Source data such as elevation and boundary data is assumed to be available in
directories specified by project.py
The output sww file is stored in directory named after the scenario, i.e
slide or fixed_wave.

The scenario is defined by a triangular mesh created from project.polygon,
the elevation data and a tsunami wave generated by a submarine mass failure.

Geoscience Australia, 2004-present
"""



#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------
# Standard modules
import os
import time
import sys
import random

# Related major packages
import anuga
from anuga.abstract_2d_finite_volumes.util import add_directories

home = os.getenv('INUNDATIONHOME')
scenariodir = add_directories(home, ["data","mem_time_test", "triangles",
                                     "serial"])


file = 'CAIRNS.sww'
file_path = os.path.join(scenariodir, file)

h = 'CAIRNS.msh'
file_pathh = os.path.join(scenariodir, h)

def runex(l,a):

#------------------------------------------------------------------------------
# Create the triangular mesh and domain based on 
# overall clipping polygon with a tagged
# boundary and interior regions as defined in project.py
#------------------------------------------------------------------------------
    domain = anuga.create_domain_from_regions([(0.0,0.0),(l,l),(0.0,l),(l,0.0)],
                                    boundary_tags={'top': [0],
                                                   'right': [1],
                                                   'bottom': [2],
                                                   'left': [3]},
                                    maximum_triangle_area=a,
                                    mesh_filename=file_pathh
                                    #,interior_regions=INTERIORREGIONS#,
                                    #use_cache=True,
                                    #verbose=True)
                                    )

    number=len(domain)

                               
#------------------------------------------------------------------------------
# Setup parameters of computational domain
#------------------------------------------------------------------------------
    domain.set_name('CAIRNS.sww') # Name of sww file
    domain.set_datadir(scenariodir)                       # Store sww output here
#------------------------------------------------------------------------------
# Setup initial conditions
#------------------------------------------------------------------------------

    def topography(x,y):
        return 0.0

    tide = 100.0
    friction = 0.0
    domain.set_quantity('stage', tide)
    domain.set_quantity('friction', friction) 
    domain.set_quantity('elevation',topography,alpha=0.1)



#------------------------------------------------------------------------------
# Setup boundary conditions
#------------------------------------------------------------------------------

    Bi = anuga.Dirichlet_boundary([tide, 0, 0]) # inflow
    Bo = anuga.Dirichlet_boundary([-tide, 0, 0]) # inflow
    Bs = anuga.Transmissive_stage_zero_momentum_boundary(domain) # Neutral boundary
    Br = anuga.Reflective_boundary(domain)
#Bw = anuga.Time_boundary(domain=domain,function=lambda t: [(60<t<3660)*50, 0, 0])
    domain.set_boundary({'right': Bo,
                     'bottom': Br,
                     'left': Bi,
                     'top': Br})

#------------------------------------------------------------------------------
# Evolve system through time
#------------------------------------------------------------------------------

# Save every two mins leading up to wave approaching land
    for t in domain.evolve(yieldstep=1, finaltime=2): 
        print domain.timestepping_statistics()
    

    return number

